<?php
namespace Webshop\Options;

use Ak\Orm\Entity\EntityInterface;
use Doctrine\ORM\Mapping as ORM;

/**
 * Postavka webshopa.
 *
 * @package Webshop\Options
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/webshop-options
 *
 * @ORM\Entity()
 * @ORM\Table(name="wp_options", options={"charset": "utf8mb4", "collate": "utf8mb4_general_ci"})
 */
class Option implements
    EntityInterface,
    OptionInterface
{
    /**
     * @var int
     *
     * @ORM\Id()
     * @ORM\GeneratedValue("AUTO")
     * @ORM\Column(name="option_id", type="bigint", options={"unsigned": true})
     */
    protected $id;

    /**
     * @var string
     *
     * @ORM\Column(name="option_name", type="string", length=191, unique=true)
     */
    protected $name;

    /**
     * @var mixed
     *
     * @ORM\Column(name="option_value", type="text")
     */
    protected $value;

    /**
     * @var bool
     *
     * @ORM\Column(name="autoload", type="string", length=20)
     */
    protected $isAutoloaded = 'no';

    /**
     * Option constructor.
     *
     * @param string $name
     * @param bool $isAutoloaded
     * @param mixed $value
     */
    public function __construct(string $name, bool $isAutoloaded, $value = null)
    {
        $this->name = $name;
        $this->isAutoloaded = $isAutoloaded ? 'yes' : 'no';

        if (null !== $value) {
            $this->setValue($value);
        }
    }

    /**
     * Vraća ID ove postavke.
     *
     * @return int|null
     */
    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * Vraća ime postavke.
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * Vraća vrijednost postavke.
     *
     * @return mixed
     */
    public function getValue()
    {
        if (false !== ($value = @unserialize($this->value))) {
            return $value;
        }

        return $this->value;
    }

    /**
     * Postavlja vrijednost postavke.
     *
     * @param $value
     */
    public function setValue($value): void
    {
        $this->value = is_scalar($value) ? $value : serialize($value);
    }
}