<?php
namespace Webshop\Options;

use Zend\Form\Annotation as Form;
use Webshop\Options\Service\OptionManagerInterface;

/**
 * Trait OptionsAwareTrait
 *
 * @package Webshop\Options
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/webshop-options
 */
trait OptionsAwareTrait
{
    /**
     * @var OptionManagerInterface
     * @Form\Exclude()
     */
    private $options;

    /**
     * @return OptionManagerInterface
     */
    public function getOptionManager(): OptionManagerInterface
    {
        return $this->options;
    }

    /**
     * @param OptionManagerInterface $optionManager
     */
    public function setOptionManager(OptionManagerInterface $optionManager): void
    {
        $this->options = $optionManager;
    }

    /**
     * Vraća vrijednost postavke s datim imenom.
     *
     * @param string $name
     * @param null $default
     * @return mixed
     */
    public function getOption(string $name, $default = null)
    {
        return $this->options->hasOption($name)
            ? $this->options->getOption($name)->getValue()
            : $default;
    }

    /**
     * Postavlja vrijednost postavke s datim imenom.
     *
     * @param string $name
     * @param $value
     */
    public function setOption(string $name, $value): void
    {
        $option = $this->options->hasOption($name)
            ? $this->options->getOption($name)
            : $this->options->createOption($name);

        $option->setValue($value);
    }

    /**
     * Briše postavku.
     *
     * @param string $name
     */
    public function removeOption(string $name): void
    {
        $this->options->removeOption($name);
    }
}