<?php
namespace WebshopTest\Options;

use Webshop\Options\Option;
use Webshop\Options\OptionInterface;
use Zend\Hydrator\ReflectionHydrator;

/**
 * Class OptionTest
 *
 * @package WebshopTest\Options
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/webshop-options
 */
final class OptionTest extends AbstractTestCase
{
    /**
     * @throws \Doctrine\DBAL\DBALException
     */
    public function testCanCreateOptions()
    {
        $option = new Option('some_option', true, 'some value');
        $this->persistEntity($option);

        $conn = $this->getConnection();
        $row = $conn->query('SELECT * FROM wp_options WHERE option_id = 1')->fetch();

        $this->assertEquals('some_option', $row['option_name']);
        $this->assertEquals('some value', $row['option_value']);
        $this->assertEquals('yes', $row['autoload']);
    }

    /**
     * @throws \Doctrine\DBAL\DBALException
     */
    public function testCanReadOptions()
    {
        $conn = $this->getConnection();
        $conn->insert('wp_options', [
            'option_name' => 'some option',
            'option_value' => 'some value',
            'autoload' => 'yes',
        ]);

        $em = $this->getEntityManager();
        $query = $em->createQueryBuilder()
            ->select('o')
            ->from(Option::class, 'o')
            ->where('o.isAutoloaded = :autoload')
            ->setParameter('autoload', 'yes')
            ->getQuery();

        $results = $query->getResult();
        $this->assertCount(1, $results);

        /** @var OptionInterface $option */
        $option = $results[0];

        $this->assertEquals('some option', $option->getName());
        $this->assertEquals('some value', $option->getValue());
    }

    public function testCanUnserializeValues()
    {
        $option = new Option('some', false);
        $hydrator = new ReflectionHydrator();

        /** @var Option $option */
        $option = $hydrator->hydrate([
            'value' => 'a:0:{}',
        ], $option);

        $this->assertEquals([], $option->getValue());
    }
}